==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/Database/AmazonElastiCacheCacheNode.md <==
# AmazonElastiCacheCacheNode


```text
aws-20210730/Resource/Database/AmazonElastiCacheCacheNode
```

```text
include('aws-20210730/Resource/Database/AmazonElastiCacheCacheNode')
```



| Illustration | AmazonElastiCacheCacheNode | AmazonElastiCacheCacheNodeCard | AmazonElastiCacheCacheNodeGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Database/AmazonElastiCacheCacheNode.png) | ![illustration for AmazonElastiCacheCacheNode](../../../aws-20210730/Resource/Database/AmazonElastiCacheCacheNode.Local.png) | ![illustration for AmazonElastiCacheCacheNodeCard](../../../aws-20210730/Resource/Database/AmazonElastiCacheCacheNodeCard.Local.png) | ![illustration for AmazonElastiCacheCacheNodeGroup](../../../aws-20210730/Resource/Database/AmazonElastiCacheCacheNodeGroup.Local.png) |




## AmazonElastiCacheCacheNode

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElastiCacheCacheNode
include('aws-20210730/Resource/Database/AmazonElastiCacheCacheNode')

' renders the element
AmazonElastiCacheCacheNode('AmazonElastiCacheCacheNode', 'Amazon Elasti Cache Cache Node', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElastiCacheCacheNode
include('aws-20210730/Resource/Database/AmazonElastiCacheCacheNode')

' renders the element
AmazonElastiCacheCacheNode('AmazonElastiCacheCacheNode', 'Amazon Elasti Cache Cache Node', 'an optional tech label')
@enduml
```

## AmazonElastiCacheCacheNodeCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElastiCacheCacheNodeCard
include('aws-20210730/Resource/Database/AmazonElastiCacheCacheNode')

' renders the element
AmazonElastiCacheCacheNodeCard('AmazonElastiCacheCacheNodeCard', 'Amazon Elasti Cache Cache Node Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElastiCacheCacheNodeCard
include('aws-20210730/Resource/Database/AmazonElastiCacheCacheNode')

' renders the element
AmazonElastiCacheCacheNodeCard('AmazonElastiCacheCacheNodeCard', 'Amazon Elasti Cache Cache Node Card', 'an optional description')
@enduml
```

## AmazonElastiCacheCacheNodeGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElastiCacheCacheNodeGroup
include('aws-20210730/Resource/Database/AmazonElastiCacheCacheNode')

' renders the element
AmazonElastiCacheCacheNodeGroup('AmazonElastiCacheCacheNodeGroup', 'Amazon Elasti Cache Cache Node Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElastiCacheCacheNodeGroup
include('aws-20210730/Resource/Database/AmazonElastiCacheCacheNode')

' renders the element
AmazonElastiCacheCacheNodeGroup('AmazonElastiCacheCacheNodeGroup', 'Amazon Elasti Cache Cache Node Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/aws-20210730/Resource/Database/AmazonElastiCacheCacheNode.md <==
# AmazonElastiCacheCacheNode


```text
aws-20210730/Resource/Database/AmazonElastiCacheCacheNode
```

```text
include('aws-20210730/Resource/Database/AmazonElastiCacheCacheNode')
```



| Illustration | AmazonElastiCacheCacheNode | AmazonElastiCacheCacheNodeCard | AmazonElastiCacheCacheNodeGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/Database/AmazonElastiCacheCacheNode.png) | ![illustration for AmazonElastiCacheCacheNode](../../../aws-20210730/Resource/Database/AmazonElastiCacheCacheNode.Local.png) | ![illustration for AmazonElastiCacheCacheNodeCard](../../../aws-20210730/Resource/Database/AmazonElastiCacheCacheNodeCard.Local.png) | ![illustration for AmazonElastiCacheCacheNodeGroup](../../../aws-20210730/Resource/Database/AmazonElastiCacheCacheNodeGroup.Local.png) |




## AmazonElastiCacheCacheNode

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElastiCacheCacheNode
include('aws-20210730/Resource/Database/AmazonElastiCacheCacheNode')

' renders the element
AmazonElastiCacheCacheNode('AmazonElastiCacheCacheNode', 'Amazon Elasti Cache Cache Node', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElastiCacheCacheNode
include('aws-20210730/Resource/Database/AmazonElastiCacheCacheNode')

' renders the element
AmazonElastiCacheCacheNode('AmazonElastiCacheCacheNode', 'Amazon Elasti Cache Cache Node', 'an optional tech label')
@enduml
```

## AmazonElastiCacheCacheNodeCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElastiCacheCacheNodeCard
include('aws-20210730/Resource/Database/AmazonElastiCacheCacheNode')

' renders the element
AmazonElastiCacheCacheNodeCard('AmazonElastiCacheCacheNodeCard', 'Amazon Elasti Cache Cache Node Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElastiCacheCacheNodeCard
include('aws-20210730/Resource/Database/AmazonElastiCacheCacheNode')

' renders the element
AmazonElastiCacheCacheNodeCard('AmazonElastiCacheCacheNodeCard', 'Amazon Elasti Cache Cache Node Card', 'an optional description')
@enduml
```

## AmazonElastiCacheCacheNodeGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElastiCacheCacheNodeGroup
include('aws-20210730/Resource/Database/AmazonElastiCacheCacheNode')

' renders the element
AmazonElastiCacheCacheNodeGroup('AmazonElastiCacheCacheNodeGroup', 'Amazon Elasti Cache Cache Node Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonElastiCacheCacheNodeGroup
include('aws-20210730/Resource/Database/AmazonElastiCacheCacheNode')

' renders the element
AmazonElastiCacheCacheNodeGroup('AmazonElastiCacheCacheNodeGroup', 'Amazon Elasti Cache Cache Node Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
